@@ -45,11 +45,11 @@ def map_user_artist(artist):
         'id': artist['ART_ID'],
         'name': artist['ART_NAME'],
         'link': 'https://www.deezer.com/artist/'+str(artist['ART_ID']),
-        'picture': 'https://api.deezer.com/artist/'+str(artist['ART_ID'])+'/image',
-        'picture_small': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_ID'])+'/56x56-000000-80-0-0.jpg',
-        'picture_medium': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_ID'])+'/250x250-000000-80-0-0.jpg',
-        'picture_big': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_ID'])+'/500x500-000000-80-0-0.jpg',
-        'picture_xl': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_ID'])+'/1000x1000-000000-80-0-0.jpg',
+        'picture': 'https://api.deezer.com/artist/'+str(artist['ART_PICTURE'])+'/image',
+        'picture_small': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_PICTURE'])+'/56x56-000000-80-0-0.jpg',
+        'picture_medium': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_PICTURE'])+'/250x250-000000-80-0-0.jpg',
+        'picture_big': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_PICTURE'])+'/500x500-000000-80-0-0.jpg',
+        'picture_xl': 'https://e-cdns-images.dzcdn.net/images/artist/'+str(artist['ART_PICTURE'])+'/1000x1000-000000-80-0-0.jpg',
         'nb_fan': artist['NB_FAN'],
         'tracklist': 'https://api.deezer.com/artist/'+str(artist['ART_ID'])+'/top?limit=50',
         'type': 'artist'
@@ -82,7 +82,7 @@ def map_user_playlist(playlist, default_user_name=""):
     return {
         'id': playlist['PLAYLIST_ID'],
         'title': playlist['TITLE'],
-        'description': playlist['DESCRIPTION'],
+        'description': playlist.get('DESCRIPTION', ''),
         'nb_tracks': playlist['NB_SONG'],
         'link': 'https://www.deezer.com/playlist/'+str(playlist['PLAYLIST_ID']),
         'picture': 'https://api.deezer.com/playlist/'+str(playlist['PLAYLIST_ID'])+'/image',
